@@ -3,8 +3,14 @@ require 'spec_helper'
 describe 'cinder::api' do
 
   shared_examples_for 'cinder api' do
+    let :pre_condition do
+      "class { '::cinder::keystone::authtoken':
+         password => 'foo',
+      }"
+    end
+
     let :req_params do
-      {:keystone_password => 'foo'}
+      {}
     end
 
     describe 'with only required params' do
@@ -46,31 +52,16 @@ describe 'cinder::api' do
         is_expected.to contain_cinder_config('DEFAULT/os_region_name').with(
          :value => '<SERVICE DEFAULT>'
         )
-        is_expected.to contain_cinder_config('keystone_authtoken/auth_uri').with(
-         :value => 'http://localhost:5000'
-        )
-        is_expected.to contain_cinder_config('keystone_authtoken/auth_url').with(
-         :value => 'http://localhost:35357'
-        )
-        is_expected.to contain_cinder_config('keystone_authtoken/project_name').with(
-         :value => 'services'
-        )
-        is_expected.to contain_cinder_config('keystone_authtoken/username').with(
-         :value => 'cinder'
-        )
-        is_expected.to contain_cinder_config('keystone_authtoken/password').with(
-         :value => 'foo'
-        )
-        is_expected.to contain_cinder_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_password').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_tenant').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_auth_url').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('keymgr/api_class').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('keymgr/encryption_api_url').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('keymgr/encryption_auth_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('key_manager/api_class').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('oslo_middleware/enable_proxy_headers_parsing').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('DEFAULT/osapi_volume_listen_port').with('value' => '<SERVICE DEFAULT>')
       end
     end
 
@@ -85,22 +76,6 @@ describe 'cinder::api' do
       it { is_expected.to contain_cinder_config('DEFAULT/nova_catalog_info').with_value('compute:nova:publicURL') }
     end
 
-    describe 'without deprecated keystone_authtoken parameters' do
-      let :params do
-        req_params.merge({
-          'keystone_user'   => 'dummy',
-          'keystone_tenant' => 'mytenant',
-          'identity_uri'    => 'https://127.0.0.1:35357/deprecated',
-          'auth_uri'        => 'https://127.0.0.1:5000/deprecated',
-        })
-      end
-
-      it { is_expected.to contain_cinder_config('keystone_authtoken/auth_url').with_value('https://127.0.0.1:35357/deprecated') }
-      it { is_expected.to contain_cinder_config('keystone_authtoken/username').with_value('dummy') }
-      it { is_expected.to contain_cinder_config('keystone_authtoken/project_name').with_value('mytenant') }
-      it { is_expected.to contain_cinder_config('keystone_authtoken/auth_uri').with_value('https://127.0.0.1:5000/deprecated') }
-    end
-
     describe 'with a custom region for nova' do
       let :params do
         req_params.merge({'os_region_name' => 'MyRegion'})
@@ -112,6 +87,17 @@ describe 'cinder::api' do
       end
     end
 
+    describe 'with a customized port' do
+      let :params do
+        req_params.merge({'osapi_volume_listen_port' => 9999})
+      end
+      it 'should customize the port' do
+        is_expected.to contain_cinder_config('DEFAULT/osapi_volume_listen_port').with(
+          :value => 9999
+        )
+      end
+    end
+
     describe 'with an OpenStack privileged account' do
 
       context 'with all needed params' do
@@ -206,7 +192,6 @@ describe 'cinder::api' do
     describe 'with sync_db set to false' do
       let :params do
         {
-          :keystone_password => 'dummy',
           :enabled           => true,
           :sync_db           => false,
         }
@@ -253,7 +238,7 @@ describe 'cinder::api' do
         req_params.merge({ :keymgr_encryption_auth_url => 'http://localhost:5000/v3' })
       end
 
-      it { is_expected.to contain_cinder_config('keymgr/encryption_auth_url').with(
+      it { is_expected.to contain_cinder_config('barbican/auth_endpoint').with(
         :value => 'http://localhost:5000/v3'
       )}
     end
@@ -297,17 +282,6 @@ describe 'cinder::api' do
       )}
     end
 
-    describe "with deprecated memcached servers for keystone authtoken" do
-      let :params do
-        req_params.merge({
-          :memcached_servers => '1.1.1.1:11211',
-        })
-      end
-      it 'configures memcached servers' do
-        is_expected.to contain_cinder_config('keystone_authtoken/memcached_servers').with_value('1.1.1.1:11211')
-      end
-    end
-
     describe 'with a custom osapi_max_limit' do
       let :params do
         req_params.merge({'osapi_max_limit' => '10000'})
@@ -325,7 +299,10 @@ describe 'cinder::api' do
 
       let :pre_condition do
         "include ::apache
-         class { 'cinder': rabbit_password => 'secret' }"
+         class { 'cinder': rabbit_password => 'secret' }
+         class { '::cinder::keystone::authtoken':
+           password => 'foo',
+         }"
       end
 
       it 'configures cinder-api service with Apache' do
@@ -344,7 +321,10 @@ describe 'cinder::api' do
 
       let :pre_condition do
         "include ::apache
-         class { 'cinder': rabbit_password => 'secret' }"
+         class { 'cinder': rabbit_password => 'secret' }
+         class { '::cinder::keystone::authtoken':
+           password => 'foo',
+         }"
       end
 
       it_raises 'a Puppet::Error', /Invalid service_name/
@@ -380,15 +360,15 @@ describe 'cinder::api' do
     describe 'with barbican parameters' do
       let :params do
         req_params.merge!({
-          :keymgr_api_class           => 'cinder.keymgr.barbican.BarbicanKeyManager',
+          :keymgr_api_class           => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
           :keymgr_encryption_api_url  => 'https://localhost:9311/v1',
           :keymgr_encryption_auth_url => 'https://localhost:5000/v3',
         })
       end
       it 'should set keymgr parameters' do
-        is_expected.to contain_cinder_config('keymgr/api_class').with_value('cinder.keymgr.barbican.BarbicanKeyManager')
-        is_expected.to contain_cinder_config('keymgr/encryption_api_url').with_value('https://localhost:9311/v1')
-        is_expected.to contain_cinder_config('keymgr/encryption_auth_url').with_value('https://localhost:5000/v3')
+        is_expected.to contain_cinder_config('key_manager/api_class').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
+        is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('https://localhost:9311/v1')
+        is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('https://localhost:5000/v3')
       end
     end
 
@@ -400,7 +380,7 @@ describe 'cinder::api' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
+          :os_workers     => 8,
           :fqdn           => 'some.host.tld',
           :concat_basedir => '/var/lib/puppet/concat',
         }))
